function [ S , r ] = metricfps_new( K, D)
%METRICFPS Samples K vertices from V by using farthest point sampling.
% The farthest point sampling uses the metric
% given by matrix D
% -  K is the number of samples
% -  D is a n-by-n matrix, such that D(i,j) contains distance between
%    vertices i and j.
% Returns
% -  S is a K-dimensional vector that includes the indeces of the K sample
%    vertices.
% -  r is a K-dimensional vector of sampling radii




S = zeros(K,1);
r = zeros(K,1);
[r(1), idx] = max(D(:));
[S(1),S(2)] = ind2sub(size(D),idx);


d = D(:,S(1));

for i=2:K
    [r(i),m] = max(d);
    S(i) = m(1);
    d = min(D(:,S(i)),d);
end

S = S(1:K);

end

